@@ -13,7 +13,7 @@
 ##############################################################################
 """Widgets Demo Implementation
 
-$Id: browser.py 77034 2007-06-25 12:57:23Z srichter $
+$Id: browser.py 81280 2007-10-31 16:50:06Z srichter $
 """
 __docformat__ = "reStructuredText"
 
@@ -25,10 +25,11 @@ from zope.annotation.interfaces import IAttributeAnnotatable
 from zope.publisher import browser
 from zope.schema.fieldproperty import FieldProperty
 from zope.pagetemplate.interfaces import IPageTemplate
-from zope.app.session.interfaces import ISession
+from zope.session.interfaces import ISession
 
 from z3c.form.interfaces import IWidgets
-from z3c.form import form, field
+from z3c.form import button, form, field
+from z3c.form.browser import checkbox
 from z3c.form.interfaces import HIDDEN_MODE
 from z3c.formdemo.widgets import interfaces
 from z3c.template.interfaces import ILayoutTemplate
@@ -41,11 +42,15 @@ class AllFields(persistent.Persistent):
     asciiField = FieldProperty(interfaces.IAllFields['asciiField'])
     asciiLineField = FieldProperty(interfaces.IAllFields['asciiLineField'])
     boolField = FieldProperty(interfaces.IAllFields['boolField'])
+    checkboxBoolField = FieldProperty(
+        interfaces.IAllFields['checkboxBoolField'])
     bytesField = FieldProperty(interfaces.IAllFields['bytesField'])
     bytesLineField = FieldProperty(interfaces.IAllFields['bytesLineField'])
     choiceField = FieldProperty(interfaces.IAllFields['choiceField'])
     optionalChoiceField = FieldProperty(
         interfaces.IAllFields['optionalChoiceField'])
+    promptChoiceField = FieldProperty(
+        interfaces.IAllFields['promptChoiceField'])
     dateField = FieldProperty(interfaces.IAllFields['dateField'])
     datetimeField = FieldProperty(interfaces.IAllFields['datetimeField'])
     decimalField = FieldProperty(interfaces.IAllFields['decimalField'])
@@ -74,15 +79,33 @@ getAllFields = factory(AllFields)
 
 class AllFieldsForm(form.EditForm):
     """A form showing all fields."""
+    form.extends(form.EditForm)
     fields = field.Fields(interfaces.IAllFields).omit(
         'dictField', 'objectField')
+    fields['checkboxBoolField'].widgetFactory = \
+        checkbox.SingleCheckBoxFieldWidget
+
+    buttons = form.EditForm.buttons + \
+              button.Buttons(
+                 button.ImageButton(name='pressme', image=u'pressme.png')
+                 )
+
+    label = 'Widgets Demo'
+
+    @button.handler(buttons['pressme'])
+    def handlePressMe(self, action):
+        self.status = u'Press me was clicked!'
 
     def getContent(self):
         return interfaces.IAllFields(self.context)
 
     def updateWidgets(self):
-        super(AllFieldsForm, self).updateWidgets()
+        self.widgets = zope.component.getMultiAdapter(
+            (self, self.request, self.getContent()), IWidgets)
+        self.widgets.update()
         self.widgets['hiddenField'].mode = HIDDEN_MODE
+        self.widgets['promptChoiceField'].prompt = True
+        self.widgets['promptChoiceField'].update()
 
     def __call__(self):
         self.update()
