@@ -13,7 +13,7 @@
 ##############################################################################
 """Widgets Demo Interfaces
 
-$Id: interfaces.py 76728 2007-06-17 13:35:02Z rogerineichen $
+$Id: interfaces.py 79470 2007-09-04 22:34:23Z srichter $
 """
 __docformat__ = "reStructuredText"
 import datetime
@@ -57,10 +57,16 @@ class IAllFields(zope.interface.Interface):
         description=u'This is a Bool field.',
         default=True)
 
+    checkboxBoolField = zope.schema.Bool(
+        title=u'Boolean (Checkbox)',
+        description=u'This is a Bool field displayed suing a checkbox.',
+        default=True)
+
     bytesField = zope.schema.Bytes(
         title=u'Bytes',
         description=u'This is a Bytes field.',
-        default='\10\45\n\32')
+        default='\10\45\n\32',
+        required=False)
 
     bytesLineField = zope.schema.BytesLine(
         title=u'Bytes Line',
@@ -79,6 +85,12 @@ class IAllFields(zope.interface.Interface):
         vocabulary=vocab,
         required=False)
 
+    promptChoiceField = zope.schema.Choice(
+        title=u'Choice (Explicit Prompt)',
+        description=u'This is a choice field with an explicit prompt.',
+        vocabulary=vocab,
+        required=False)
+
     dateField = zope.schema.Date(
         title=u'Date',
         description=u'This is a Date field.',
@@ -125,7 +137,7 @@ class IAllFields(zope.interface.Interface):
     intField = zope.schema.Int(
         title=u'Integer',
         description=u'This is a Int field.',
-        default=12)
+        default=12345)
 
     listField = zope.schema.List(
         title=u'List',
@@ -141,7 +153,8 @@ class IAllFields(zope.interface.Interface):
     passwordField = zope.schema.Password(
         title=u'Password',
         description=u'This is a Password field.',
-        default=u'mypwd')
+        default=u'mypwd',
+        required=False)
 
     setField = zope.schema.Set(
         title=u'Set',
