@@ -13,7 +13,7 @@
 ##############################################################################
 """Person Interfaces
 
-$Id: interfaces.py 75999 2007-05-30 17:13:58Z srichter $
+$Id: interfaces.py 82177 2007-12-07 14:37:56Z ccomb $
 """
 __docformat__ = "reStructuredText"
 import zope.interface
@@ -134,7 +134,7 @@ class IPerson(IPersonalInfo):
         required=True)
 
     employer = zope.schema.Object(
-        title=u'Mother',
-        description=u"Mother's personal info.",
+        title=u'Employer',
+        description=u"Employer's info.",
         schema=IEmployerInfo,
         required=True)
